==> jc-1.4.0.tar.gz: java/awt/dnd/DnDConstants.h <==
// public final class java.awt.dnd.DnDConstants

// class file dependencies
// @dep_class e6c8a214095f9028 java_awt_dnd_DnDConstants
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_dnd_DnDConstants_H_
#define _JC_java_awt_dnd_DnDConstants_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_dnd_DnDConstants$sub_refs	_jc_java_awt_dnd_DnDConstants$sub_refs;
typedef struct _jc_java_awt_dnd_DnDConstants$sub_nonrefs	_jc_java_awt_dnd_DnDConstants$sub_nonrefs;
typedef struct _jc_java_awt_dnd_DnDConstants$refs	_jc_java_awt_dnd_DnDConstants$refs;
typedef struct _jc_java_awt_dnd_DnDConstants$nonrefs	_jc_java_awt_dnd_DnDConstants$nonrefs;
typedef struct _jc_java_awt_dnd_DnDConstants$object	_jc_java_awt_dnd_DnDConstants$object;

typedef struct _jc_java_awt_dnd_DnDConstants$fields_struct	_jc_java_awt_dnd_DnDConstants$fields_struct;
typedef const struct _jc_java_awt_dnd_DnDConstants$vmethods	_jc_java_awt_dnd_DnDConstants$vmethods;
typedef const struct _jc_java_awt_dnd_DnDConstants$vtable	_jc_java_awt_dnd_DnDConstants$vtable;
typedef const struct _jc_java_awt_dnd_DnDConstants$vtype	_jc_java_awt_dnd_DnDConstants$vtype;

// Class fields structure
struct _jc_java_awt_dnd_DnDConstants$fields_struct {
	jint	ACTION__5fCOPY;
	jint	ACTION__5fCOPY__5fOR__5fMOVE;
	jint	ACTION__5fLINK;
	jint	ACTION__5fMOVE;
	jint	ACTION__5fNONE;
	jint	ACTION__5fREFERENCE;
};
extern _jc_java_awt_dnd_DnDConstants$fields_struct _jc_java_awt_dnd_DnDConstants$class_fields;

// Constructors
extern void _jc_java_awt_dnd_DnDConstants$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_dnd_DnDConstants$object *);

// Virtual methods structure
struct _jc_java_awt_dnd_DnDConstants$vmethods {
};

// Vtable
struct _jc_java_awt_dnd_DnDConstants$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_dnd_DnDConstants$vmethods	java_awt_dnd_DnDConstants;
};

// Vtype
struct _jc_java_awt_dnd_DnDConstants$vtype {
	_jc_type			type;
	_jc_java_awt_dnd_DnDConstants$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_dnd_DnDConstants$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_dnd_DnDConstants$refs {
    _jc_java_awt_dnd_DnDConstants$sub_refs	java_awt_dnd_DnDConstants;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_dnd_DnDConstants$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_dnd_DnDConstants$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_dnd_DnDConstants$sub_nonrefs	java_awt_dnd_DnDConstants;
};

// Object instance structure
struct _jc_java_awt_dnd_DnDConstants$object {
	_jc_java_awt_dnd_DnDConstants$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_dnd_DnDConstants$vtype	*vtype;
	_jc_java_awt_dnd_DnDConstants$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_dnd_DnDConstants$vtype _jc_java_awt_dnd_DnDConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_dnd_DnDConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_dnd_DnDConstants$class_object;

#endif	/* _JC_java_awt_dnd_DnDConstants_H_ */

==> jc-1.4.6.tar.gz: java/awt/dnd/DnDConstants.h <==
// public final class java.awt.dnd.DnDConstants

// class file dependencies
// @dep_class e6c8a214095f9028 java_awt_dnd_DnDConstants
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_dnd_DnDConstants_H_
#define _JC_java_awt_dnd_DnDConstants_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_dnd_DnDConstants$sub_refs	_jc_java_awt_dnd_DnDConstants$sub_refs;
typedef struct _jc_java_awt_dnd_DnDConstants$sub_nonrefs	_jc_java_awt_dnd_DnDConstants$sub_nonrefs;
typedef struct _jc_java_awt_dnd_DnDConstants$refs	_jc_java_awt_dnd_DnDConstants$refs;
typedef struct _jc_java_awt_dnd_DnDConstants$nonrefs	_jc_java_awt_dnd_DnDConstants$nonrefs;
typedef struct _jc_java_awt_dnd_DnDConstants$object	_jc_java_awt_dnd_DnDConstants$object;

typedef struct _jc_java_awt_dnd_DnDConstants$fields_struct	_jc_java_awt_dnd_DnDConstants$fields_struct;
typedef const struct _jc_java_awt_dnd_DnDConstants$vmethods	_jc_java_awt_dnd_DnDConstants$vmethods;
typedef const struct _jc_java_awt_dnd_DnDConstants$vtable	_jc_java_awt_dnd_DnDConstants$vtable;
typedef const struct _jc_java_awt_dnd_DnDConstants$vtype	_jc_java_awt_dnd_DnDConstants$vtype;

// Class fields structure
struct _jc_java_awt_dnd_DnDConstants$fields_struct {
	jint	ACTION__5fCOPY;
	jint	ACTION__5fCOPY__5fOR__5fMOVE;
	jint	ACTION__5fLINK;
	jint	ACTION__5fMOVE;
	jint	ACTION__5fNONE;
	jint	ACTION__5fREFERENCE;
};
extern _jc_java_awt_dnd_DnDConstants$fields_struct _jc_java_awt_dnd_DnDConstants$class_fields;

// Constructors
extern void _jc_java_awt_dnd_DnDConstants$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_dnd_DnDConstants$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_dnd_DnDConstants$vmethods {
};

// Vtable
struct _jc_java_awt_dnd_DnDConstants$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_dnd_DnDConstants$vmethods	java_awt_dnd_DnDConstants;
};

// Vtype
struct _jc_java_awt_dnd_DnDConstants$vtype {
	_jc_type			type;
	_jc_java_awt_dnd_DnDConstants$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_dnd_DnDConstants$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_dnd_DnDConstants$refs {
    _jc_java_awt_dnd_DnDConstants$sub_refs	java_awt_dnd_DnDConstants;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_dnd_DnDConstants$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_dnd_DnDConstants$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_dnd_DnDConstants$sub_nonrefs	java_awt_dnd_DnDConstants;
};

// Object instance structure
struct _jc_java_awt_dnd_DnDConstants$object {
	_jc_java_awt_dnd_DnDConstants$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_dnd_DnDConstants$vtype	*vtype;
	_jc_java_awt_dnd_DnDConstants$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_dnd_DnDConstants$vtype _jc_java_awt_dnd_DnDConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_dnd_DnDConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_dnd_DnDConstants$class_object;

#endif	/* _JC_java_awt_dnd_DnDConstants_H_ */
